@@ -78,26 +78,29 @@ class YahooFinanceDownloader:
         import datetime
         import pydatum
         
-        content_json = json.loads(content)
-
         result = PriceModel()
 
-        meta = content_json['chart']['result'][0]['meta']
-        #result.symbol = meta.symbol
-        market_price = meta['regularMarketPrice']
-        result.value = Decimal(str(market_price))
+        try:
+            content_json = json.loads(content)
 
-        result.currency = meta['currency']
-        
-        # Date/time
-        datum = pydatum.Datum()
-        # apply UTC offset
-        #offset = meta['gmtoffset']
-        seconds = meta['regularMarketTime']
-        #seconds = seconds + offset
+            meta = content_json['chart']['result'][0]['meta']
+            #result.symbol = meta.symbol
+            market_price = meta['regularMarketPrice']
+            result.value = Decimal(str(market_price))
 
-        datum.from_timestamp(seconds)
-        result.datum = datum
+            result.currency = meta['currency']
+            
+            # Date/time
+            datum = pydatum.Datum()
+            # apply UTC offset
+            #offset = meta['gmtoffset']
+            seconds = meta['regularMarketTime']
+            #seconds = seconds + offset
+
+            datum.from_timestamp(seconds)
+            result.datum = datum
+        except Exception as e:
+            raise ValueError('Error getting price from JSON. Load: {meta}. Error: {e}')
 
         return result
 
